#!/usr/bin/ruby
#
#   check-fetch-letsencrypt-cronjob
#
# DESCRIPTION:
#   Checks fetch-letsencrypt cronjob
#
# OUTPUT:
#   plain text
#
# PLATFORMS:
#   Linux
#
# DEPENDENCIES:
#   gem: sensu-plugin
#
# USAGE:
#
#

require 'sensu-plugin/check/cli'

class FetchLetsencryptCronjobChecker < Sensu::Plugin::Check::CLI
  option :fetch_letsencrypt_cronjob,
         description: 'fetch-letsencrypt cronjob - defaults to /etc/cron.d/fetch-letsencrypt',
         short: '-c /etc/cron.d/fetch-letsencrypt',
         long: '--fetch-letsencrypt-cronjob /etc/cron.d/fetch-letsencrypt',
         default: '/etc/cron.d/fetch-letsencrypt'
  
  def run
    if File.file?(config[:fetch_letsencrypt_cronjob])
      unless File.open(config[:fetch_letsencrypt_cronjob]).grep(/^#.*fetch-letsencrypt.*$/).empty?
        age = Time.now.to_i - File.mtime(config[:fetch_letsencrypt_cronjob]).to_i
        if age > 1800 && age <= 86_400
          warning "fetch-letsencrypt cronjob #{config[:fetch_letsencrypt_cronjob]} exists but is inactive for more than thirty minuntes (#{age}s)!"
        elsif age > 86_400
          critical "fetch-letsencrypt cronjob #{config[:fetch_letsencrypt_cronjob]} exists but is inactive for more than one day (#{age}s)!"
        else
          ok "fetch-letsencrypt cronjob exists but is temporarily inactive (#{age}s)."
        end
      else
        if File.open(config[:fetch_letsencrypt_cronjob]).grep(/^.*fetch-letsencrypt.*$/).empty?
          critical "fetch-letsencrypt cronjob #{config[:fetch_letsencrypt_cronjob]} exists but has no call on fetch-letsencrypt.*"
        else
          ok "fetch-letsencrypt cronjob #{config[:fetch_letsencrypt_cronjob]} exists and is active."
        end
      end
    else
      critical "fetch-letsencrypt cronjob #{config[:fetch_letsencrypt_cronjob]} NOT found!"
    end
  end
end
